@@ -1063,7 +1063,6 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             self.transaction.connect("cancellable-changed", self.on_driver_changes_cancellable_changed)
             self.transaction.connect("finished", self.on_driver_changes_finish)
             self.transaction.connect("error", self.on_driver_changes_error)
-            self.transaction.set_debconf_frontend("gnome")
             self.transaction.run()
             self.button_driver_revert.set_sensitive(False)
             self.button_driver_apply.set_sensitive(False)
@@ -1177,9 +1176,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                     if (linux_meta and
                         linux_meta not in self.driver_changes):
                         # Install the linux metapackage
-                        lmp = self.apt_cache[linux_meta]
-                        if not lmp.is_installed:
-                            self.driver_changes.append(lmp)
+                        self.driver_changes.append(self.apt_cache[linux_meta])
         except KeyError:
             pass
 
