@@ -22,6 +22,8 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
+# FIXME: why does this pass kapps around?????
+
 from __future__ import absolute_import, print_function
 
 import apt_pkg
@@ -30,13 +32,10 @@ from gettext import gettext as _
 import os
 import subprocess
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-from PyQt4 import uic
-
-from PyKDE4.kdecore import ki18n, i18n, KUrl
-from PyKDE4.kdeui import KApplication, KMessageBox, KIcon, KWindowSystem
-from PyKDE4.kio import KFileDialog
+from PyQt5 import uic
+from PyQt5.QtCore import *
+from PyQt5.QtGui import *
+from PyQt5.QtWidgets import *
 
 import softwareproperties
 import softwareproperties.distro
@@ -66,24 +65,26 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     self.datadir = datadir
 
     global kapp
-    kapp = KApplication()
+    kapp = QApplication.instance()
+    kapp.setWindowIcon(QIcon.fromTheme("applications-other"))
 
     self.userinterface = SoftwarePropertiesKDEUI(datadir)
-    self.userinterface.setWindowIcon(KIcon("applications-other"))
-    self.userinterface.button_auth_restore.setIcon(KIcon("edit-undo"))
-    self.userinterface.button_add_auth.setIcon(KIcon("list-add"))
-    self.userinterface.button_auth_remove.setIcon(KIcon("list-remove"))
-    self.userinterface.button_remove.setIcon(KIcon("list-remove"))
-    self.userinterface.button_edit.setIcon(KIcon("document-edit"))
-    self.userinterface.button_add.setIcon(KIcon("list-add"))
-    self.userinterface.button_add_cdrom.setIcon(KIcon("media-optical"))
+    self.userinterface.setWindowIcon(QIcon.fromTheme("applications-other"))
+    self.userinterface.button_auth_restore.setIcon(QIcon.fromTheme("edit-undo"))
+    self.userinterface.button_add_auth.setIcon(QIcon.fromTheme("list-add"))
+    self.userinterface.button_auth_remove.setIcon(QIcon.fromTheme("list-remove"))
+    self.userinterface.button_remove.setIcon(QIcon.fromTheme("list-remove"))
+    self.userinterface.button_edit.setIcon(QIcon.fromTheme("document-edit"))
+    self.userinterface.button_add.setIcon(QIcon.fromTheme("list-add"))
+    self.userinterface.button_add_cdrom.setIcon(QIcon.fromTheme("media-optical"))
     translate_widget(self.userinterface)
     self.userinterface.show()
-    if attachWinID is not None:
-        KWindowSystem.setMainWindow(self.userinterface, int(attachWinID))
+    # FIXME: winid not handled
+    #if attachWinID is not None:
+        #KWindowSystem.setMainWindow(self.userinterface, int(attachWinID))
 
     # rejected() signal from Close button
-    kapp.connect(self.userinterface.buttonBox, SIGNAL("rejected()"), self.on_close_button)
+    self.userinterface.buttonBox.rejected.connect(self.on_close_button)
 
     self.userinterface.buttonBox.button(QDialogButtonBox.Reset).setEnabled(False)
 
@@ -101,26 +102,26 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     self.show_isv_sources()
     self.show_cdrom_sources()
 
-    kapp.connect(self.userinterface.checkbutton_source_code, SIGNAL("clicked()"), self.on_checkbutton_source_code_toggled)
-    kapp.connect(self.userinterface.button_auth_restore, SIGNAL("clicked()"), self.on_restore_clicked)
-    kapp.connect(self.userinterface.button_add_auth, SIGNAL("clicked()"), self.add_key_clicked)
-    kapp.connect(self.userinterface.button_auth_remove, SIGNAL("clicked()"), self.remove_key_clicked)
-    kapp.connect(self.userinterface.checkbutton_popcon, SIGNAL("toggled(bool)"), self.on_checkbutton_popcon_toggled)
-    kapp.connect(self.userinterface.checkbutton_auto_update, SIGNAL("toggled(bool)"), self.on_auto_update_toggled)
-    kapp.connect(self.userinterface.combobox_update_interval, SIGNAL("currentIndexChanged(int)"), self.on_combobox_update_interval_changed)
-    kapp.connect(self.userinterface.button_remove, SIGNAL("clicked()"), self.on_remove_clicked)
-    kapp.connect(self.userinterface.button_edit, SIGNAL("clicked()"), self.on_edit_clicked)
-    kapp.connect(self.userinterface.button_add_cdrom, SIGNAL("clicked()"), self.on_button_add_cdrom_clicked)
-    kapp.connect(self.userinterface.button_add, SIGNAL("clicked()"), self.on_add_clicked)
-    kapp.connect(self.userinterface.treeview_sources, SIGNAL("itemChanged(QTreeWidgetItem*, int)"), self.on_isv_source_toggled)
-    kapp.connect(self.userinterface.treeview_sources, SIGNAL("itemClicked(QTreeWidgetItem*, int)"), self.on_treeview_sources_cursor_changed)
-    kapp.connect(self.userinterface.treeview_cdroms, SIGNAL("itemChanged(QTreeWidgetItem*, int)"), self.on_cdrom_source_toggled)
-    kapp.connect(self.userinterface.treeview2, SIGNAL("itemClicked(QTreeWidgetItem*, int)"), self.on_treeview_keys_cursor_changed)
+    self.userinterface.checkbutton_source_code.clicked.connect(self.on_checkbutton_source_code_toggled)
+    self.userinterface.button_auth_restore.clicked.connect(self.on_restore_clicked)
+    self.userinterface.button_add_auth.clicked.connect(self.add_key_clicked)
+    self.userinterface.button_auth_remove.clicked.connect(self.remove_key_clicked)
+    self.userinterface.checkbutton_popcon.toggled.connect(self.on_checkbutton_popcon_toggled)
+    self.userinterface.checkbutton_auto_update.toggled.connect(self.on_auto_update_toggled)
+    self.userinterface.combobox_update_interval.currentIndexChanged.connect(self.on_combobox_update_interval_changed)
+    self.userinterface.button_remove.clicked.connect(self.on_remove_clicked)
+    self.userinterface.button_edit.clicked.connect(self.on_edit_clicked)
+    self.userinterface.button_add_cdrom.clicked.connect(self.on_button_add_cdrom_clicked)
+    self.userinterface.button_add.clicked.connect(self.on_add_clicked)
+    self.userinterface.treeview_sources.itemChanged.connect(self.on_isv_source_toggled)
+    self.userinterface.treeview_sources.itemClicked.connect(self.on_treeview_sources_cursor_changed)
+    self.userinterface.treeview_cdroms.itemChanged.connect(self.on_cdrom_source_toggled)
+    self.userinterface.treeview2.itemClicked.connect(self.on_treeview_keys_cursor_changed)
     button_close = self.userinterface.buttonBox.button(QDialogButtonBox.Close)
-    button_close.setIcon(KIcon("dialog-close"))
+    button_close.setIcon(QIcon.fromTheme("dialog-close"))
     button_revert = self.userinterface.buttonBox.button(QDialogButtonBox.Reset)
-    button_revert.setIcon(KIcon("edit-undo"))
-    kapp.connect(button_revert, SIGNAL("clicked()"), self.on_button_revert_clicked)
+    button_revert.setIcon(QIcon.fromTheme("edit-undo"))
+    button_revert.clicked.connect(self.on_button_revert_clicked)
 
     self.init_distro()
     self.show_distro()
@@ -146,11 +147,8 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     " setup the widgets that allow configuring the release upgrades "
     i = self.get_release_upgrades_policy()
 
-    # FIXME: hack for LP: #944876
-    i = (i + 1) % 3
-
     self.userinterface.combobox_release_upgrades.setCurrentIndex(i)
-    kapp.connect(self.userinterface.combobox_release_upgrades, SIGNAL("currentIndexChanged(int)"), self.on_combobox_release_upgrades_changed)
+    self.userinterface.combobox_release_upgrades.currentIndexChanged.connect(self.on_combobox_release_upgrades_changed)
 
   def init_auto_update(self):
     """ Set up the widgets that allow to configure the update automation """
@@ -192,9 +190,9 @@ class SoftwarePropertiesKDE(SoftwareProperties):
       self.userinterface.radiobutton_updates_download.setEnabled(False)
       self.userinterface.radiobutton_updates_notify.setEnabled(False)
 
-    kapp.connect(self.userinterface.radiobutton_updates_download, SIGNAL("toggled(bool)"), self.set_update_automation_level)
-    kapp.connect(self.userinterface.radiobutton_updates_inst_sec, SIGNAL("toggled(bool)"), self.set_update_automation_level)
-    kapp.connect(self.userinterface.radiobutton_updates_notify, SIGNAL("toggled(bool)"), self.set_update_automation_level)
+    self.userinterface.radiobutton_updates_download.toggled.connect(self.set_update_automation_level)
+    self.userinterface.radiobutton_updates_inst_sec.toggled.connect(self.set_update_automation_level)
+    self.userinterface.radiobutton_updates_notify.toggled.connect(self.set_update_automation_level)
 
   def show_auto_update_level(self):
     """Represent the level of update automation in the user interface"""
@@ -242,7 +240,7 @@ class SoftwarePropertiesKDE(SoftwareProperties):
         self.checkboxComps[checkbox] = comp
 
         # setup the callback and show the checkbutton
-        kapp.connect(checkbox, SIGNAL("clicked()"), self.on_component_toggled)
+        checkbox.clicked.connect(self.on_component_toggled)
         self.vbox_dist_comps.addWidget(checkbox)
 
     # Setup the checkbuttons for the child repos / updates
@@ -264,7 +262,7 @@ class SoftwarePropertiesKDE(SoftwareProperties):
         checkbox.setObjectName(template.name)
         self.checkboxTemplates[checkbox] = template
         # setup the callback and show the checkbutton
-        kapp.connect(checkbox, SIGNAL("clicked()"), self.on_checkbutton_child_toggled)
+        checkbox.clicked.connect(self.on_checkbutton_child_toggled)
         self.vbox_updates.addWidget(checkbox)
 
     # If no components are enabled there will be no need for updates
@@ -274,7 +272,7 @@ class SoftwarePropertiesKDE(SoftwareProperties):
         self.userinterface.vbox_updates_frame.setEnabled(True)
 
     self.init_mirrors()
-    kapp.connect(self.userinterface.combobox_server, SIGNAL("activated(int)"), self.on_combobox_server_changed)
+    self.userinterface.combobox_server.activated.connect(self.on_combobox_server_changed)
 
   def init_mirrors(self):
     # Intiate the combobox which allows the user to specify a server for all
@@ -396,9 +394,6 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     """ set the release upgrades policy """
     i = self.userinterface.combobox_release_upgrades.currentIndex()
 
-    # FIXME: hack for LP: #944876
-    i = (i - 1) % 3
-
     self.set_release_upgrades_policy(i)
 
   def on_combobox_server_changed(self, combobox):
@@ -433,6 +428,7 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     Sync the components of all main sources (excluding cdroms),
     child sources and source code sources
     """
+    # FIXME: I find it rather questionable whether sender will work with pyqt doing weird signal handling
     tickBox = kapp.sender()
     if tickBox.checkState() == Qt.Checked:
         self.enable_component(str(tickBox.objectName()))
@@ -675,7 +671,8 @@ class SoftwarePropertiesKDE(SoftwareProperties):
         title = _("Error importing selected file")
         text = _("The selected file may not be a GPG key file " \
                 "or it might be corrupt.")
-        KMessageBox.sorry(self.userinterface, text, title)
+        #KMessageBox.sorry(self.userinterface, text, title)
+        QMessageBox.warning(self.userinterface, title, text)
       self.show_keys()
 
   def remove_key_clicked(self):
@@ -688,7 +685,8 @@ class SoftwarePropertiesKDE(SoftwareProperties):
       title = _("Error removing the key")
       text = _("The key you selected could not be removed. "
                "Please report this as a bug.")
-      KMessageBox.sorry(self.userinterface, text, title)
+      #KMessageBox.sorry(self.userinterface, text, title)
+      QMessageBox.warning(self.userinterface, title, text)
     self.show_keys()
 
   def on_restore_clicked(self):
@@ -735,7 +733,8 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     except SystemError as msg:
       title = _("CD Error")
       text = _("<big><b>Error scanning the CD</b></big>\n\n%s")%msg
-      KMessageBox.sorry(self.userinterface, text, title)
+      #KMessageBox.sorry(self.userinterface, text, title)
+      QMessageBox.warning(self.userinterface, title, text)
       return
     finally:
       apt_pkg.config.set("Dir::Etc::sourcelist",saved_entry)
